type BinInput = Uint8Array | ArrayBuffer | string | number[];
declare function _encodeUtf8Polyfill(str: string): Uint8Array;
declare function _decodeUtf8Polyfill(buf: Uint8Array): string;
declare function stringToUInt8Array(text: string): Uint8Array;
declare function Uint8ArrayToString(bin: Uint8Array): string;
declare function toUint8Array(data: BinInput): Uint8Array;
declare function joinToUint8Array(...args: BinInput[] | BinInput[][]): Uint8Array;
declare function toHex(bin: BinInput): string;
declare function fromHex(hexString: string): Uint8Array;
declare function toBase64(bin: BinInput): string;
declare function toBase64Url(bin: BinInput): string;
declare function fromBase64(s: string): Uint8Array;
/** Compare contents of binary arrays */
declare function equalBinary(a: ArrayBuffer | Uint8Array, b: ArrayBuffer | Uint8Array): boolean;
declare function jsonToUint8Array(json: any): Uint8Array | never;
declare function Uint8ArrayToJson<T = any>(data: Uint8Array): T | never;
declare function Uint8ArrayToHexDump(buffer: Uint8Array | ArrayBuffer | String | Array<number>, blockSize?: number): string | false;

/** Get random bytes using window.crypto if available. Else use a poor fallback solution. */
declare function randomUint8Array(length?: number): Uint8Array;
declare const CRYPTO_DEFAULT_HASH_ALG = "SHA-256";
declare const CRYPTO_DEFAULT_ALG = "AES-GCM";
declare const CRYPTO_DEFAULT_DERIVE_ALG = "PBKDF2";
declare const CRYPTO_DEFAULT_DERIVE_ITERATIONS = 100000;
declare function digest(message: BinInput, algorithm?: AlgorithmIdentifier): Promise<Uint8Array>;
declare function deriveKeyPbkdf2(secret: BinInput, opt?: {
    iterations?: number;
    salt?: BinInput;
}): Promise<CryptoKey>;
declare function encrypt(data: Uint8Array, key: CryptoKey): Promise<Uint8Array>;
declare function decrypt(data: Uint8Array, key: CryptoKey): Promise<Uint8Array>;

declare function csv(data: any[], headerRow: string[]): string;

type Json = string | number | boolean | null | {
    [property: string]: Json;
} | Json[];
interface ObjectStorage<T = any> {
    setItem(key: string, value: T): void;
    getItem(key: string): T | undefined;
    removeItem(key: string): void;
    clear(): void;
    allKeys(): string[];
}
type NestedArray<T> = T | Array<NestedArray<T>>;

declare function arrayUnique<T>(x: T[]): T[];
declare function arrayMinus<T>(x: T[], y: T[]): T[];
declare function arrayUnion<T>(...a: T[][]): T[];
/** `[1,[2,3]]` becomes `[1,2,3]` */
declare function arrayFlatten<T>(...list: NestedArray<T>[]): T[];
declare function arrayIntersection<T>(x: T[], y: T[]): T[];
declare function arraySymmetricDifference<T>(x: T[], y: T[]): T[];
declare function arrayRemoveElement<T>(arr: T[], el: T): T[];
/** Only have it once in the set */
declare function arraySetElement<T>(arr: T[], el: T): T[];
declare function arrayFilterInPlace<T>(array: T[], fn: (el: T) => boolean): T[];
declare function arrayToggleInPlace<T>(array: T[], el: T): T[];
declare function arrayEmptyInPlace<T>(array: T[]): T[];
declare function arraySorted<T>(arr: Iterable<T> | ArrayLike<T>, cond?: ((a: T, b: T) => number) | undefined): T[];
declare function arraySortedNumbers(arr: number[]): number[];
declare function arrayIsEqual<T>(array1: T[], array2: T[]): boolean;
declare function arrayShuffleInPlace<T>(array: T[]): T[];
declare function arrayShuffle<T>(array: T[]): T[];
/** Randomly shuffle the order of the array's elements. Force to have a different order if array has more than one element. */
declare function arrayShuffleForce<T>(array: T[]): T[];
declare function arrayRandomElement<T>(array: T[]): T;
declare function arrayMax<T>(...array: NestedArray<T>[]): T;
declare function arrayMin<T>(...array: NestedArray<T>[]): T;
declare function arraySum(...array: NestedArray<number>[]): number;
declare function arrayAvg(...array: NestedArray<number>[]): number;
declare function arrayBatches<T>(array: T[], chunckLength: number): T[][];
declare function createArray<T>(size?: number, item?: T | ((index: number) => T)): T[];

declare function useBase(alphaOrBase: string | number): {
    encode: (source: BinInput, padToLength?: number) => string;
    decode: (source: string, padToLength?: number) => Uint8Array;
};
declare const encodeBase32: (source: BinInput, padToLength?: number) => string;
declare function decodeBase32(s: string): Uint8Array;

declare const encodeBase16: (source: BinInput, padToLength?: number) => string;
declare const decodeBase16: (source: string, padToLength?: number) => Uint8Array;
declare const encodeBase58: (source: BinInput, padToLength?: number) => string;
declare const decodeBase58: (source: string, padToLength?: number) => Uint8Array;
declare const encodeBase62: (source: BinInput, padToLength?: number) => string;
declare const decodeBase62: (source: string, padToLength?: number) => Uint8Array;
declare function estimateSizeForBase(bytes: number, base: number): number;

declare const toCamelCase: (s: string) => string;
declare function toCapitalize(s: string): string;
declare function toCapitalizeWords(s: string): string;
declare function fromCamelCase(str: string, separator?: string): string;

declare function stringToBoolean(value?: string, defaultValue?: boolean): boolean;
declare function stringToInteger(value?: string, defaultValue?: number): number;
declare function stringToFloat(value?: string, defaultValue?: number): number;
declare function valueToBoolean(value?: any, defaultValue?: boolean): boolean;
declare function valueToInteger(value?: any, defaultValue?: number): number;
declare function valueToFloat(value?: any, defaultValue?: number): number;
declare function valueToString(value?: any, defaultValue?: string): string;
declare const toFloat: typeof valueToFloat;
declare const toInt: typeof valueToInteger;
declare const toString: typeof valueToString;
declare const toBool: typeof valueToBoolean;
interface RenderMessagesOptions {
    trace?: boolean;
    pretty?: boolean;
}
declare function formatMessages(messages: any[], opt?: RenderMessagesOptions): any[];
declare function renderMessages(messages: any[], opt?: RenderMessagesOptions): string;
declare function fixBrokenUth8String(brokenString: string): string;

declare const DAY_MS = 86400000;
type DayValue = number;
type DayInput = DayValue | number | string | Date | [number, number?, number?];
declare function dayYear(day: DayValue): DayValue;
declare function dayMonth(day: DayValue): DayValue;
declare function dayDay(day: DayValue): DayValue;
declare function dayToParts(day: DayValue): [number, number, number];
declare function dayToDate(day: DayValue, gmt?: boolean): Date;
declare function dayFromToday(): DayValue;
declare function dayFromAny(value: DayInput, gmt?: boolean): DayValue | undefined;
declare function dayToDateGMT(day: DayValue): Date;
declare function dayFromDate(date: Date, gmt?: boolean): DayValue;
declare function dayFromDateGMT(date: Date): DayValue;
declare function dayToTimestamp(day: DayValue, gmt?: boolean): number;
declare function dayFromTimestamp(ms: number, gmt?: boolean): DayValue;
declare function dayToString(day: DayValue, sep?: string): string;
declare function dayFromParts(year: number, month?: number, day?: number): DayValue | undefined;
declare function dayFromString(value: string): DayValue | undefined;
declare function dayMonthStart(day: DayValue, offset?: number): DayValue;
declare function dayYearStart(day: DayValue, offset?: number): DayValue;
declare function dayOffset(day: DayValue, offset: number): DayValue;
declare function dayDiff(left: DayValue, right: DayValue): number;

type DayInputLegacy = DayInput | Day;
/**
 * Date represented as positive integer value. Years smaller 0 are not supported.
 * @deprecated
 */
declare class Day {
    days: DayValue;
    get value(): number;
    constructor(days?: DayInputLegacy);
    static fromNumber(n: number): Day;
    static fromString(dateString: string): Day | undefined;
    static fromDate(date: Date, gmt?: boolean): Day;
    static fromDateGMT(date: Date): Day;
    static from(value: DayInputLegacy, gmt?: boolean): Day | undefined;
    toNumber(): number;
    /** Just for future extensions */
    toJson(): number;
    toString(sep?: string): string;
    toDate(gmt?: boolean): Date;
    toDateGMT(): Date;
    get year(): number;
    get month(): number;
    get day(): number;
    dayOffset(offset: number): Day;
    monthStart(): Day;
    yearStart(): Day;
    /** Very stupid approach, only works for days <= 28 */
    monthOffset(offset: number): Day;
    daysUntil(otherDay: DayInputLegacy): number;
    yesterday(): Day;
    tomorrow(): Day;
}
declare function forEachDay(from: DayInputLegacy, to: DayInputLegacy, handler: (date: Day) => Promise<void> | void): Promise<void>;
declare function today(): Day;
/** @deprecated */
declare function day(days?: DayInputLegacy): Day;
declare function dateStringToDays(dateString: string): number;

type DecimalValue = number;
type DecimalInput = number | string | DecimalValue;
declare function decimal(value: DecimalInput, decimalPlaces?: number): DecimalValue;
declare function decimalFromCents(value: DecimalInput, decimalPlaces?: number): DecimalValue;
declare function decimalToCents(value: DecimalInput, decimalPlaces?: number): number;
declare function decimalCentsPart(value: DecimalInput, decimalPlaces?: number): DecimalValue;

declare function deepEqual(a: any, b: any, hash?: WeakSet<object>): boolean;
/** Strip properties with value `undefined` in place */
declare function deepStripUndefinedInPlace(a: any, hash?: WeakSet<object>): any;
declare function deepMerge(target: any, ...sources: any[]): any;

declare const escapeHTML: (s: string) => string;
declare const unescapeHTML: (s: string) => string;

type Primitive = null | undefined | string | number | boolean | symbol | bigint;
declare function isObject(obj: unknown): obj is object;
declare function isPrimitive(obj: unknown): obj is Primitive;
declare function isArray(obj: unknown): obj is Array<any>;
declare function isRecord(obj: unknown): obj is Record<string, any>;
declare function isString(obj: unknown): obj is string;
declare function isNumber(obj: unknown): obj is number;
declare function isInteger(obj: unknown): obj is number;
declare function isSafeInteger(obj: unknown): obj is number;
declare function isBoolean(obj: unknown): obj is boolean;
declare function isNullOrUndefined(obj: unknown): obj is null | undefined;
declare function isUint8Array(obj: unknown): obj is Uint8Array;

declare function jsonStringifySorted(obj: any, indent?: number | undefined): string;
type EntryProcessor = (key: string, value: any) => any;
/**
 * Similar to JSON.stringify but can handle circular references
 */
declare function jsonStringifySafe(obj: any, replacer?: EntryProcessor | null, spaces?: string | number | null, cycleReplacer?: EntryProcessor): string;
declare const jsonStringify: typeof jsonStringifySafe;

declare function getSecureRandom(): number;
declare function getSecureRandomIfPossible(): number;
declare function randomBoolean(bias?: number): boolean;
/** max is not included, min is included */
declare function randomInt(max?: number, min?: number): number;
declare function randomFloat(max?: number, min?: number): number;
declare function between(min: number, value: number, max: number): number;
/** See also arraySum */
declare function sum(array: number[]): number;
/** See also arrayAvg */
declare function avg(array: number[]): number;
/** Fancy prime number check ;) */
declare function isPrimeRX(value: number): boolean;
declare function isPrime(value: number): boolean;
/** Deterministic random */
declare function seededRandom(max?: number, min?: number, seed?: number): number;

/** Like `.map()` for object. Return new key and value or `undefined` to delete. */
declare function objectMap<T = any>(obj: any, fn: (key: string, value: any) => [key: string, value: T] | T | undefined | null): Record<string, T>;
/** Merge right into left object. If dispose is defined, it will be combined. Left can be a complex object i.e. a insantiated class. */
declare function objectMergeDisposable<A extends object, B extends object>(a: A, b: B): A & B;
declare function objectIsEmpty(obj: object): boolean;

declare function parseOrderby(value?: string): {
    field: string;
    orderby: string;
    asc: boolean;
    desc: boolean;
};
declare function composeOrderby(field: string, asc?: boolean): string;
declare function cmp(a: any, b: any, asc?: boolean): -1 | 0 | 1;
declare function sortedOrderby<T>(values: T[], ...orderby: string[]): T[];

/** Ensure a valid file name. Unsupported characters get a `replacement`, default: `_` */
declare function toValidFilename(string: string, replacement?: string): string | never;

declare function escapeRegExp(value: RegExp | string): string;

type RoundingMode = (value: number) => number;
declare const isHalf: (value: number) => boolean;
declare const isEven: (value: number) => boolean;
declare const roundUp: RoundingMode;
declare const roundDown: RoundingMode;
declare const roundHalfUp: RoundingMode;
/**
 * Round a number with half values to nearest odd integer.
 */
declare const roundHalfOdd: RoundingMode;
/**
 * Round a number with half values to nearest integer farthest from zero.
 */
declare const roundHalfAwayFromZero: RoundingMode;
/**
 * Round a number with half values down.
 */
declare const roundHalfDown: RoundingMode;
/**
 * Round a number with half values to nearest even integer.
 * https://wiki.c2.com/?BankersRounding
 */
declare const roundHalfEven: RoundingMode;
/**
 * Round a number with half values to nearest integer closest to zero.
 */
declare const roundHalfTowardsZero: RoundingMode;

interface SortableItem {
    sort_weight: number;
}
declare function startSortWeight(items: SortableItem[]): number;
declare function endSortWeight(items: SortableItem[]): number;
declare function moveSortWeight(newIndex: number, oldIndex: number, items: SortableItem[]): number;
declare function sortedItems<T extends SortableItem>(items: T[]): T[];

/** CRDT compatible sorting with a single operation. Default name is `sort` */
declare function useSorted<S extends Record<string, any>>(config?: {
    getter?: (item: S) => number;
}): {
    start: (items: S[]) => number;
    end: (items: S[]) => number;
    between: (lower?: number, upper?: number) => number;
    move: (newIndex: number, oldIndex: number, sortableItems: S[]) => number;
    items: <T extends S>(items: T[]) => T[];
};

declare function linkifyPlainText(text: string): string;
declare function toHumanReadableUrl(url: string): string;
declare function encodeQuery(data: Record<string, any>): string;
declare function parseQuery(queryString: string): any;

/**
 * Call a create function if key does not yet exist on an object. Returns the found or created object. Example:
 *
 * ```js
 * function createRoom(room, rooms) { return new Room() }
 * ensureKey(rooms, room, createRoom).enter()
 * ```
 */
declare function ensureKey<T>(obj: Record<string, T>, key: string, createFn: (key?: string, obj?: Record<string, T>) => T): T;
/**
 * Call a create function if key does not yet exist on an object. Returns the found or created object. Example:
 *
 * ```js
 * async function fetchItem(id, cache) { ... }
 * let data = await ensureKey(cache, id, fetchItem)
 * ```
 */
declare function ensureKeyAsync<T>(obj: Record<string, T>, key: string, createFn: (key?: string, obj?: Record<string, T>) => Promise<T>): Promise<T>;
declare function size(obj: any): any;
declare function last<T>(array?: T[]): T | undefined;
declare function empty(value: any): boolean;
declare function cloneObject<T>(obj: T): T;
declare function cloneJsonObject<T = Json>(obj: T): T;
/**
 * Cache result of a function. Same arguments have to always return the same result in order to get expected optimization!
 *
 * ```
 * const square = memoize((value) => value * value)`
 * square(2) // == 2
 * ```
 */
declare function memoize<In, Out>(fn: (arg: In) => Out): (arg: In) => Out;
declare function memoizeAsync<In extends any[], Out extends Promise<any>>(fn: (...arg: In) => Out): (...arg: In) => Promise<Out>;
/** Repeat `count` times. Starts with `0` */
declare function forTimes<T = undefined>(count: number, fn: (i: number, count: number) => T): T[];

declare function regExpString(rx: string | RegExp): string;
declare function regExpEscape(str: string): string;
declare class XRX {
    lookBehind: {
        rx: RegExp;
        expect: boolean;
    } | undefined;
    namedGroups: Record<string, number>;
    names: string[];
    rx: RegExp;
    constructor(pattern: string | RegExp, flags?: string);
    get lastIndex(): number;
    set lastIndex(index: number);
    _handleMatch(m: any): any;
    exec(str: string): any;
    execAll(str: string): any[];
    replace(str: string, replacement: string | Function): string;
}

type DisposerFunction = () => any | Promise<any>;
type Disposer = DisposerFunction | {
    dispose?: Function | Promise<unknown>;
    cleanup?: Function | Promise<unknown>;
};
interface Disposable {
    dispose: UseDispose;
}
interface UseDisposeConfig {
    name?: string;
}
declare function useDispose(config?: string | UseDisposeConfig): (() => Promise<void>) & {
    track: (obj?: Disposer) => DisposerFunction | undefined;
    add: (obj?: Disposer) => DisposerFunction | undefined;
    untrack: (disposable: Disposer) => Promise<void>;
    dispose: () => Promise<void>;
    exec: () => Promise<void>;
    getSize(): number;
};
type UseDispose = ReturnType<typeof useDispose>;
/** @deprecated use `useDispose` instead */
declare const useDisposer: typeof useDispose;
declare function useDefer(config?: {
    mode?: 'lifo' | 'fifo';
}): ((expectSync?: boolean) => Promise<void>) & {
    add: (obj: Disposer) => void;
    exec: (expectSync?: boolean) => Promise<void>;
    getSize(): number;
};
type UseDefer = ReturnType<typeof useDefer>;
declare function useTimeout(fn: Function, timeout?: number): DisposerFunction;
declare function useInterval(fn: Function, interval: number): DisposerFunction;
declare function useEventListener(emitter: any, eventName: string, fn: (ev?: any) => void, ...args: any[]): DisposerFunction;

type Mutex = (fn: Function, elseFn?: Function) => boolean;
type AsyncMutex = (fn: Function, elseFn?: Function) => Promise<boolean>;
declare function useMutex(): Mutex;
declare function useAsyncMutex(): AsyncMutex;

type EmitterHandler = (...objs: any[]) => void;
type EmitterAllHandler<T = string> = (key: T, ...objs: any[]) => void;
declare type ListenerSignature<L> = {
    [E in keyof L]: (...args: any[]) => any;
};
declare interface DefaultListener {
    [k: string]: (...args: any[]) => any;
}
declare class Emitter<RemoteListener extends ListenerSignature<RemoteListener> = DefaultListener, LocalListener extends ListenerSignature<LocalListener> = RemoteListener> implements Disposable {
    subscribers: any;
    subscribersOnAny: any[];
    dispose: (() => Promise<void>) & {
        track: (obj?: Disposer | undefined) => DisposerFunction | undefined;
        add: (obj?: Disposer | undefined) => DisposerFunction | undefined;
        untrack: (disposable: Disposer) => Promise<void>;
        dispose: () => Promise<void>;
        exec: () => Promise<void>;
        getSize(): number;
    };
    call: RemoteListener;
    emit<U extends keyof RemoteListener>(event: U, ...args: Parameters<RemoteListener[U]>): Promise<boolean>;
    onAny(fn: EmitterHandler): void;
    on<U extends keyof LocalListener>(event: U, listener: LocalListener[U]): DisposerFunction;
    onCall(handlers: Partial<LocalListener>): void;
    once<U extends keyof LocalListener>(event: U, listener: LocalListener[U]): DisposerFunction;
    off<U extends keyof LocalListener>(event: U, listener: LocalListener[U]): this;
    removeAllListeners(): this;
}
declare global {
    interface ZeedGlobalContext {
        emitter?: Emitter;
    }
    interface ZeedGlobalEmitter {
    }
}
/** Global emitter that will listen even across modules */
declare function getGlobalEmitter(): Emitter<ZeedGlobalEmitter>;
declare const messages: Emitter<DefaultListener, DefaultListener>;
declare function lazyListener(emitter: any, listenerKey?: string): (key?: string, skipUnmatched?: boolean) => Promise<any>;

interface PoolConfig {
    maxParallel?: number;
}
type PoolTaskFn<T = any> = (taskInfo?: PoolTask<T>) => Promise<T>;
declare enum PoolTaskState {
    waiting = 0,
    running = 1,
    finished = 2
}
/** Task */
interface PoolTask<T> {
    readonly id: string;
    readonly task: PoolTaskFn<T>;
    readonly done: Function;
    readonly setMax: (max: number) => void;
    readonly setResolved: (resolved: number) => void;
    readonly incResolved: (inc?: number) => void;
    state: PoolTaskState;
    priority: number;
    /** Same groups are executed only one at a time */
    group?: string;
    max: number;
    resolved: number;
    result?: T;
    payload?: unknown;
}
declare enum PoolTaskIdConflictResolution {
    /** Tasks with same `id` are replaced. Last wins */
    replace = 0,
    /** Tasks with same `id` ??? */
    memoize = 1,
    /** Tasks with same `id` throw error */
    error = 2
}
interface PoolTaskEvents {
    didUpdate(max: number, resolved: number, presentMax: number, presentResolved: number): void;
    didStart(id: string): void;
    didCancel(id: string): void;
    didFinish(): void;
    didResolve(id: string, value: any): void;
    didReject(id: string, error: any): void;
}
declare function usePool<T = any>(config?: PoolConfig): {
    events: Emitter<PoolTaskEvents, PoolTaskEvents>;
    cancel: (id: string) => void;
    cancelAll: () => void;
    enqueue: <P>(task: PoolTaskFn<T>, config?: {
        id?: string | undefined;
        max?: number | undefined;
        resolved?: number | undefined;
        group?: string | undefined;
        idConflictResolution?: PoolTaskIdConflictResolution | undefined;
        payload?: P | undefined;
    }) => {
        id: string;
        promise: Promise<any>;
        dispose: () => void;
        cancel: () => void;
    };
    dispose: () => void;
    waitFinishAll: () => Promise<unknown>;
};
type Pool = ReturnType<typeof usePool>;

declare function createPromise<T>(): [Promise<T>, any, any];
/** Sleep for `milliSeconds`. Example 1s: `await sleep(1000)` */
declare function sleep(milliSeconds: number): Promise<void>;
declare function immediate(): Promise<void>;
declare const timeoutReached: unique symbol;
declare function timeout<T>(promise: Promise<T>, milliSeconds: number, timeoutValue?: symbol): Promise<T | typeof timeoutValue>;
declare const timoutError: Error;
declare function isTimeout(value: any): boolean;
declare function tryTimeout<T>(promise: Promise<T>, milliSeconds: number): Promise<T | undefined>;
/** Wait for `event` on `obj` to emit. Resolve with result or reject on `timeout` */
declare function waitOn(obj: any, event: string, timeoutMS?: number): Promise<any>;
declare function isPromise<T>(value: Promise<T> | T): value is Promise<T>;
/** This is exactly what Prose.resolve(x) is supposed to be: return a Promise no matter what type x is */
declare function promisify<T>(value: Promise<T> | T): Promise<T>;
/**
 *  Like ReturnType but for async functions.
 *  From https://www.jpwilliams.dev/how-to-unpack-the-return-type-of-a-promise-in-typescript
 */
type AsyncReturnType<T extends (...args: any) => any> = T extends (...args: any) => Promise<infer U> ? U : T extends (...args: any) => infer U ? U : any;

declare enum LogLevel {
    all = -1,
    debug = 0,
    info = 1,
    warn = 2,
    error = 3,
    fatal = 4,
    off = Infinity
}
declare const LogLevelAlias: Record<string, LogLevel>;
type LogLevelAliasKey = keyof typeof LogLevelAlias;
type LogLevelAliasType = LogLevel | boolean | LogLevelAliasKey;
interface LogMessage {
    level: LogLevel;
    name: string;
    messages: any[];
    line?: number;
    file?: string;
    timestamp?: number;
}
type LogHandler = (msg: LogMessage) => void;
interface LoggerInterface {
    (...messages: any[]): void;
    /** @deprecated use .level = LogLevel.off or LogLevel.all */
    active: boolean;
    level: LogLevel;
    debug(...messages: any[]): void;
    info(...messages: any[]): void;
    warn(...messages: any[]): void;
    error(...messages: any[]): void;
    assert(cond: any, ...messages: any[]): void;
    /** @deprecated use .assert */
    assertEqual(value: any, expected: any, ...args: any[]): void;
    /** @deprecated use .assert */
    assertNotEqual(value: any, expected: any, ...args: any[]): void;
    extend(prefix: string): LoggerInterface;
    factory?: LoggerContextInterface;
    label: string;
}
interface LoggerContextInterface {
    (name?: string, level?: LogLevelAliasType): LoggerInterface;
    registerHandler(handler: LogHandler): void;
    setFilter(namespaces: string): void;
    setHandlers(handlers?: (LogHandler | undefined | null)[]): void;
    setLock(lock: boolean): void;
    /** When true emits a short log message for each Logger when being set up first time. */
    setDebug(debug: boolean): void;
    setLogLevel(level?: LogLevel): void;
    setFactory(factory: (name?: string) => LoggerInterface): void;
}
interface LogHandlerOptions {
    level?: LogLevel;
    filter?: string;
    colors?: boolean;
    levelHelper?: boolean;
    nameBrackets?: boolean;
    padding?: number;
    fill?: number;
    stack?: boolean | number;
    time?: boolean;
    pretty?: boolean;
}
declare function LoggerContext(_prefix?: string): LoggerContextInterface;

type TaskFn<T = any> = () => Promise<T>;
interface TaskEvents {
    didUpdate(max: number, resolved: number): void;
    didStart(max: number): void;
    didCancel(): void;
    didFinish(): void;
}
/** Guarentee serial execution of tasks. Able to wait, pause, resume and cancel all. */
declare class SerialQueue extends Emitter<TaskEvents> {
    private queue;
    private waitToFinish;
    private currentTask?;
    private log;
    private countMax;
    private countResolved;
    private paused;
    name: string;
    constructor(opt?: {
        name?: string;
        logLevel?: LogLevel;
    });
    private performNext;
    /** Enqueue task to be executed when all other tasks are done. Except `immediate = true`. */
    enqueue<T>(task: TaskFn<T>, opt?: {
        immediate?: boolean;
        name?: string;
    }): Promise<T>;
    /** If a task is already performing, execute immediately. Otherwise enqueue as usual. */
    enqueueReentrant<T>(task: TaskFn<T>, opt?: {
        name?: string;
    }): Promise<T>;
    /** Remove all tasks from queue that are not yet executing. */
    cancelAll(_unblock?: boolean): Promise<void>;
    /** Pause execution after current task is finished. */
    pause(): Promise<void>;
    /** Resume paused queue. */
    resume(): void;
    /** Wait for all tasks to finish */
    wait(): Promise<unknown>;
    get isPaused(): boolean;
    get hasTasks(): boolean;
}

/**
 * A special throttle implementation that tries to distribute execution
 * in an optimal way.
 *
 * **Functionality:** For UI usage the function is executed on first occasion (`leading`).
 * If more calls follow it will again be executed at end (`trailing`).
 * If the next call is inside the timeframe, it is delayed until `trailing`.
 * This avoids timewise too close calls.
 * It is possible to `cancel` the timeout and to `flush` a call, e.g. if
 * leaving UI situation where a final call is required to write data or similar.
 */
declare function throttle<F extends (...args: any[]) => any>(callback: F, opt?: {
    delay?: number;
    trailing?: boolean;
    leading?: boolean;
}): F & {
    /** Stop all timers, do not exec nothing */
    cancel: () => void;
    /** Stop all timers and execute right now. */
    immediate: (...args: Parameters<F>) => Promise<void>;
    /** Stop all timers and execute trailing call, if exists. */
    stop: () => void;
    dispose: () => void;
};
/**
 * Debounce fits best for filtering a large peak of events.
 * For UI event filtering throttle is probably a better choice.
 *
 * **Functionality:**  It only fires after triggers pause for `delay` ms.
 */
declare function debounce<F extends (...args: any[]) => any | Promise<any>>(callback: F, opt?: {
    delay?: number;
}): F & {
    cancel: () => void;
    immediate: (...args: Parameters<F>) => Promise<void>;
    dispose: () => void;
};

declare global {
    interface ZeedGlobalContext {
    }
}
declare function getGlobalContext(): ZeedGlobalContext;

declare function isLocalHost(hostname?: string): boolean;

declare global {
    interface ZeedGlobalContext {
        logger?: any;
    }
}
declare function getGlobalLogger(): LoggerContextInterface;
declare const Logger: LoggerContextInterface;

/**
 * Very basic logger. Please take a look at the browser and node
 * optimized loggers. This one is just the absolute fallback option.
 *
 * @param level Log level
 * @returns Logger
 */
declare function LoggerConsoleHandler(opt?: LogHandlerOptions): LogHandler;

interface NamespaceFilter {
    (name: string): boolean;
    accept: RegExp[];
    reject: RegExp[];
    filter: string;
}
declare function getNamespaceFilterString(defaultNamespaceFilter: any): string;
/**
 * Filter as described here https://github.com/visionmedia/debug#wildcards
 *
 * @param filter Namespace filter
 * @returns Function to check if filter applies
 */
declare function useNamespaceFilter(filter?: string): NamespaceFilter;
declare function parseLogLevel(filter: LogLevelAliasType): LogLevel;
declare function useLevelFilter(filter?: string | number | boolean | LogLevelAliasType): (level: LogLevel) => boolean;

/**
 * Collect messages in a list.
 *
 * @param level Log level
 * @returns Logger
 */
declare function LoggerMemoryHandler(opt: LogHandlerOptions & {
    messages: LogMessage[];
}): LogHandler;

/** See http://developer.mozilla.org/en-US/docs/Web/API/MessageEvent */
interface ChannelMessageEvent {
    data: any;
    origin?: string;
    lastEventId?: string;
}
/**
 * Inspired by
 * http://developer.mozilla.org/en-US/docs/Web/API/BroadcastChannel
 * https://deno.com/deploy/docs/runtime-broadcast-channel
 * */
declare abstract class Channel extends Emitter<{
    message(event: ChannelMessageEvent): void;
    messageerror(event: ChannelMessageEvent): void;
    connect(): void;
    disconnect(): void;
    close(): void;
}> {
    id: string;
    abstract isConnected?: boolean;
    abstract postMessage(data: any): void;
    close(): void;
}
/** Very basic channel demonstrating local communication */
declare class LocalChannel extends Channel {
    isConnected: boolean;
    other?: LocalChannel;
    postMessage(data: any): void;
}
declare function createLocalChannelPair(): [LocalChannel, LocalChannel];

interface Encoder {
    encode(data: any): Promise<Uint8Array>;
    decode(data: Uint8Array): Promise<any>;
}
declare class NoopEncoder implements Encoder {
    encode(data: any): Promise<Uint8Array>;
    decode(data: Uint8Array): Promise<any>;
}
declare class JsonEncoder implements Encoder {
    encode(data: any): Promise<Uint8Array>;
    decode(data: Uint8Array): Promise<any>;
}
declare class CryptoEncoder implements Encoder {
    key: CryptoKey;
    constructor(key: CryptoKey);
    encode(data: any): Promise<Uint8Array>;
    decode(data: Uint8Array): Promise<any>;
}

interface MessageAction {
    name: string;
    id: string;
    args?: Json[];
}
interface MessageResult {
    id: string;
    result?: Json;
    error?: {
        stack?: string;
        name: string;
        message: string;
    };
}
type Message = MessageAction | MessageResult;
interface MessagesOptions {
    timeout?: number;
}
interface MessagesDefaultMethods<L> {
    dispose(): void;
    connect?(channel: Channel): void;
    options(opt: MessagesOptions): L;
}
type MessagesMethods<L> = L & MessagesDefaultMethods<L>;
type MessageDefinitions = Record<any, (...args: any) => Promise<any>>;
interface MessageHub {
    dispose(): void;
    connect: (newChannel: Channel) => void;
    listen<L extends MessageDefinitions>(newHandlers: L): void;
    send<L extends MessageDefinitions>(): MessagesMethods<L>;
}
declare const createPromiseProxy: <P extends object>(fn: (name: string, args: any[], opt: any) => Promise<unknown>, opt: MessagesOptions, predefinedMethods?: any) => P;
/**
 * RPC
 *
 * Features:
 * - Waits for connection
 * - Retries after fail
 * - Timeouts
 */
declare function useMessageHub(opt?: {
    name?: string;
    channel?: Channel;
    encoder?: Encoder;
    retryAfter?: number;
    ignoreUnhandled?: boolean;
    debug?: boolean;
    logLevel?: LogLevelAliasType;
}): MessageHub;

interface PubSubConfig {
    channel: Channel;
    encoder?: Encoder;
    name?: string;
    debug?: boolean;
}
declare class PubSub<L extends ListenerSignature<L> = DefaultListener> extends Emitter<L> {
    name: string;
    channel: Channel;
    encoder: Encoder;
    log: any;
    debug: boolean;
    get shortId(): string;
    constructor(opt: PubSubConfig);
    private emitSuper;
    emit<U extends keyof L>(event: U, ...args: Parameters<L[U]>): Promise<boolean>;
    publish: <U extends keyof L>(event: U, ...args: Parameters<L[U]>) => Promise<boolean>;
    subscribe: <U extends keyof L>(event: U, listener: L[U]) => DisposerFunction;
}
declare function usePubSub<L extends ListenerSignature<L> = DefaultListener>(opt: PubSubConfig): PubSub<L>;

type ArgumentsType<T> = T extends (...args: infer A) => any ? A : never;
type ReturnType$1<T> = T extends (...args: any) => infer R ? R : never;
interface RPCOptions<Remote> {
    /** No return values expected */
    onlyEvents?: boolean;
    /** Names of remote functions that do not need response. */
    eventNames?: (keyof Remote)[];
    /** Function to post raw message */
    post: (data: any) => void;
    /** Listener to receive raw message */
    on: (fn: (data: any) => void) => void;
    /** Custom function to serialize data */
    serialize?: (data: any) => any;
    /** Custom function to deserialize data */
    deserialize?: (data: any) => any;
}
interface RPCFn<T> {
    /** Call the remote function and wait for the result. */
    (...args: ArgumentsType<T>): Promise<Awaited<ReturnType$1<T>>>;
    /** Send event without asking for response */
    asEvent(...args: ArgumentsType<T>): void;
}
type RPCReturn<RemoteFunctions> = {
    [K in keyof RemoteFunctions]: RPCFn<RemoteFunctions[K]>;
};
declare function useRPC<RemoteFunctions = {}, LocalFunctions = {}>(functions: LocalFunctions, options: RPCOptions<RemoteFunctions>): RPCReturn<RemoteFunctions>;

interface fetchOptionType {
    /** Returns the cache mode associated with request, which is a string indicating how the request will interact with the browser's cache when fetching. */
    cache?: RequestCache;
    /** Returns the credentials mode associated with request, which is a string indicating whether credentials will be sent with the request always, never, or only when sent to a same-origin URL. */
    credentials?: RequestCredentials;
    /** Returns the kind of resource requested by request, e.g., "document" or "script". */
    destination?: RequestDestination;
    /** Returns a Headers object consisting of the headers associated with request. Note that headers added in the network layer by the user agent will not be accounted for in this object, e.g., the "Host" header. */
    headers?: Record<string, string>;
    /** Returns request's subresource integrity metadata, which is a cryptographic hash of the resource being fetched. Its value consists of multiple hashes separated by whitespace. [SRI] */
    integrity?: string;
    /** Returns a boolean indicating whether or not request can outlive the global in which it was created. */
    keepalive?: boolean;
    /** Returns request's HTTP method, which is "GET" by default. */
    method?: string;
    /** Returns the mode associated with request, which is a string indicating whether the request will use CORS, or will be restricted to same-origin URLs. */
    mode?: RequestMode;
    /** Returns the redirect mode associated with request, which is a string indicating how redirects for the request will be handled during fetching. A request will follow redirects by default. */
    redirect?: RequestRedirect;
    /** Returns the referrer of request. Its value can be a same-origin URL if explicitly set in init, the empty string to indicate no referrer, and "about:client" when defaulting to the global's default. This is used during fetching to determine the value of the `Referer` header of the request being made. */
    referrer?: string;
    /** Returns the referrer policy associated with request. This is used during fetching to compute the value of the request's referrer. */
    referrerPolicy?: ReferrerPolicy;
    /** Returns the signal associated with request, which is an AbortSignal object indicating whether or not request has been aborted, and its abort event handler. */
    signal?: AbortSignal;
    /** Returns the URL of request as a string. */
    url?: string;
    body?: any;
}
type fetchOptionsType = fetchOptionType | fetchOptionsType[];
type httpMethod = 'GET' | 'POST' | 'PUT' | 'DELETE' | 'HEAD' | 'CONNECT' | 'OPTIONS' | 'TRACE' | 'PATCH';
declare function parseBasicAuth(url: string): {
    url: string;
    username: string;
    password: string;
} | undefined;
/** Simplified `fetch` that returns `undefined` on non 200 status */
declare function fetchBasic(url: string | URL, fetchOptions?: fetchOptionsType, fetchFn?: (input: RequestInfo, init?: RequestInit) => Promise<Response>): Promise<Response | undefined>;
/** Fetch for JSON  */
declare function fetchJson<T = Json>(url: string | URL, fetchOptions?: fetchOptionsType, fetchFn?: (input: RequestInfo, init?: RequestInit) => Promise<Response>): Promise<T | undefined>;
/** Fetch for text */
declare function fetchText(url: string | URL, fetchOptions?: fetchOptionsType, fetchFn?: (input: RequestInfo, init?: RequestInit) => Promise<Response>): Promise<string | undefined>;
/** Options for fetchBasic to send data as application/x-www-form-urlencoded */
declare function fetchOptionsFormURLEncoded(data: object, method?: httpMethod): fetchOptionType;
/** Options to send data as JSON  */
declare function fetchOptionsJson(data: object, method?: httpMethod): fetchOptionType;
/** Options to pass basic auth */
declare function fetchOptionsBasicAuth(username: string, password: string): fetchOptionType;

declare function getWindow(): any | undefined;
declare function getNavigator(): any | undefined;
declare function getGlobal(): any;
declare function detect(info?: {
    ios: boolean;
    macos: boolean;
    windows: boolean;
    beaker: boolean;
    electron: boolean;
    wkwebview: boolean;
    pwa: boolean;
    pwaInstalled: boolean;
    browser: boolean;
    node: boolean;
    worker: boolean;
    test: boolean;
    jest: boolean;
    macosNative: boolean;
    iosNative: boolean;
    appleNative: boolean;
    touch: boolean;
}): {
    ios: boolean;
    macos: boolean;
    windows: boolean;
    beaker: boolean;
    electron: boolean;
    wkwebview: boolean;
    pwa: boolean;
    pwaInstalled: boolean;
    browser: boolean;
    node: boolean;
    worker: boolean;
    test: boolean;
    jest: boolean;
    macosNative: boolean;
    iosNative: boolean;
    appleNative: boolean;
    touch: boolean;
};
declare const isBrowser: () => boolean;
declare const platform: {
    ios: boolean;
    macos: boolean;
    windows: boolean;
    beaker: boolean;
    electron: boolean;
    wkwebview: boolean;
    pwa: boolean;
    pwaInstalled: boolean;
    browser: boolean;
    node: boolean;
    worker: boolean;
    test: boolean;
    jest: boolean;
    macosNative: boolean;
    iosNative: boolean;
    appleNative: boolean;
    touch: boolean;
};
/**
 * Before closing the tab/window or quitting the node process
 * allow to do something important first
 */
declare function useExitHandler(handler: () => void): void;

interface MemStorageOptions {
    objectFromString?: (data: string) => any;
    objectToString?: (data: any) => string;
}
declare class MemStorage<T = Json> implements ObjectStorage<T> {
    private store;
    constructor(_opt?: MemStorageOptions);
    setItem(key: string, value: T): void;
    getItem(key: string): T | undefined;
    removeItem(key: string): void;
    clear(): void;
    allKeys(): string[];
}

/**
 * @returns Timestamp in miliseconds
 */
declare const getTimestamp: () => number;
declare function formatMilliseconds(ms: number): string;
declare function parseDate(...dateCandidates: (string | Date)[]): Date | undefined;

declare function uuidBytes(): Uint8Array;
declare function uuidB62(bytes?: Uint8Array): string;
declare function uuidEncodeB62(bytes: Uint8Array): string;
declare function uuidDecodeB62(uuid: string): Uint8Array;
declare function uuidB32(bytes?: Uint8Array): string;
declare function uuidEncodeB32(bytes: Uint8Array): string;
declare function uuidDecodeB32(uuid: string): Uint8Array;
declare const uuidv4: () => string;
declare function uuidEncodeV4(bytes: Uint8Array): string;
declare function uuidDecodeV4(uuid: string): Uint8Array;
declare function suidBytes(): Uint8Array;
declare function suid(): string;
declare function suidDate(id: string): Date;
declare function suidBytesDate(id: Uint8Array): Date;
declare const uuid32bit: () => number;
declare const mapModes: {
    base62: {
        uuid: typeof uuidB62;
        uuidDecode: typeof uuidDecodeB62;
        uuidEncode: typeof uuidEncodeB62;
    };
    base32: {
        uuid: typeof uuidB32;
        uuidDecode: typeof uuidDecodeB32;
        uuidEncode: typeof uuidEncodeB32;
    };
    uuidv4: {
        uuid: () => string;
        uuidDecode: typeof uuidDecodeV4;
        uuidEncode: typeof uuidEncodeV4;
    };
};
declare function setUuidDefaultEncoding(mode: keyof typeof mapModes, sorted?: boolean): void;
declare function uuid(): string;
declare function uuidDecode(uuid: string): Uint8Array;
declare function uuidEncode(bytes: Uint8Array): string;
declare function uuidIsValid(uuid: string): boolean;
declare function uname(name?: string): string;
declare function qid(): string;

export { stringToUInt8Array as $, arrayShuffleInPlace as A, arrayShuffle as B, CRYPTO_DEFAULT_HASH_ALG as C, arrayShuffleForce as D, arrayRandomElement as E, arrayMax as F, arrayMin as G, arraySum as H, arrayAvg as I, Json as J, arrayBatches as K, LogHandlerOptions as L, createArray as M, encodeBase32 as N, ObjectStorage as O, decodeBase32 as P, useBase as Q, encodeBase16 as R, decodeBase16 as S, encodeBase58 as T, decodeBase58 as U, encodeBase62 as V, decodeBase62 as W, estimateSizeForBase as X, BinInput as Y, _decodeUtf8Polyfill as Z, _encodeUtf8Polyfill as _, LogHandler as a, decimalToCents as a$, Uint8ArrayToString as a0, toUint8Array as a1, joinToUint8Array as a2, toHex as a3, fromHex as a4, toBase64 as a5, toBase64Url as a6, fromBase64 as a7, equalBinary as a8, jsonToUint8Array as a9, dayDay as aA, dayToParts as aB, dayToDate as aC, dayFromToday as aD, dayFromAny as aE, dayToDateGMT as aF, dayFromDate as aG, dayFromDateGMT as aH, dayToTimestamp as aI, dayFromTimestamp as aJ, dayToString as aK, dayFromParts as aL, dayFromString as aM, dayMonthStart as aN, dayYearStart as aO, dayOffset as aP, dayDiff as aQ, DayInputLegacy as aR, Day as aS, forEachDay as aT, today as aU, day as aV, dateStringToDays as aW, DecimalValue as aX, DecimalInput as aY, decimal as aZ, decimalFromCents as a_, Uint8ArrayToJson as aa, Uint8ArrayToHexDump as ab, toCamelCase as ac, toCapitalize as ad, toCapitalizeWords as ae, fromCamelCase as af, stringToBoolean as ag, stringToInteger as ah, stringToFloat as ai, valueToBoolean as aj, valueToInteger as ak, valueToFloat as al, valueToString as am, toFloat as an, toInt as ao, toString as ap, toBool as aq, RenderMessagesOptions as ar, formatMessages as as, renderMessages as at, fixBrokenUth8String as au, DAY_MS as av, DayValue as aw, DayInput as ax, dayYear as ay, dayMonth as az, LogLevelAliasType as b, ensureKeyAsync as b$, decimalCentsPart as b0, deepEqual as b1, deepStripUndefinedInPlace as b2, deepMerge as b3, escapeHTML as b4, unescapeHTML as b5, Primitive as b6, isObject as b7, isPrimitive as b8, isArray as b9, composeOrderby as bA, cmp as bB, sortedOrderby as bC, toValidFilename as bD, escapeRegExp as bE, RoundingMode as bF, isHalf as bG, isEven as bH, roundUp as bI, roundDown as bJ, roundHalfUp as bK, roundHalfOdd as bL, roundHalfAwayFromZero as bM, roundHalfDown as bN, roundHalfEven as bO, roundHalfTowardsZero as bP, SortableItem as bQ, startSortWeight as bR, endSortWeight as bS, moveSortWeight as bT, sortedItems as bU, useSorted as bV, linkifyPlainText as bW, toHumanReadableUrl as bX, encodeQuery as bY, parseQuery as bZ, ensureKey as b_, isRecord as ba, isString as bb, isNumber as bc, isInteger as bd, isSafeInteger as be, isBoolean as bf, isNullOrUndefined as bg, isUint8Array as bh, jsonStringifySorted as bi, jsonStringifySafe as bj, jsonStringify as bk, getSecureRandom as bl, getSecureRandomIfPossible as bm, randomBoolean as bn, randomInt as bo, randomFloat as bp, between as bq, sum as br, avg as bs, isPrimeRX as bt, isPrime as bu, seededRandom as bv, objectMap as bw, objectMergeDisposable as bx, objectIsEmpty as by, parseOrderby as bz, LoggerInterface as c, parseLogLevel as c$, size as c0, last as c1, empty as c2, cloneObject as c3, cloneJsonObject as c4, memoize as c5, memoizeAsync as c6, forTimes as c7, regExpString as c8, regExpEscape as c9, timeoutReached as cA, timeout as cB, timoutError as cC, isTimeout as cD, tryTimeout as cE, waitOn as cF, isPromise as cG, promisify as cH, AsyncReturnType as cI, TaskFn as cJ, TaskEvents as cK, SerialQueue as cL, throttle as cM, debounce as cN, getGlobalContext as cO, isLocalHost as cP, getGlobalLogger as cQ, Logger as cR, LogLevel as cS, LogLevelAlias as cT, LogLevelAliasKey as cU, LogMessage as cV, LoggerContextInterface as cW, LoggerContext as cX, LoggerConsoleHandler as cY, getNamespaceFilterString as cZ, useNamespaceFilter as c_, XRX as ca, DisposerFunction as cb, Disposer as cc, Disposable as cd, useDispose as ce, UseDispose as cf, useDisposer as cg, useDefer as ch, UseDefer as ci, useTimeout as cj, useInterval as ck, useEventListener as cl, Mutex as cm, AsyncMutex as cn, useMutex as co, useAsyncMutex as cp, PoolTaskFn as cq, PoolTaskState as cr, PoolTask as cs, PoolTaskIdConflictResolution as ct, PoolTaskEvents as cu, usePool as cv, Pool as cw, createPromise as cx, sleep as cy, immediate as cz, CRYPTO_DEFAULT_ALG as d, uuidEncodeB32 as d$, useLevelFilter as d0, LoggerMemoryHandler as d1, ChannelMessageEvent as d2, Channel as d3, LocalChannel as d4, createLocalChannelPair as d5, EmitterHandler as d6, EmitterAllHandler as d7, ListenerSignature as d8, DefaultListener as d9, useRPC as dA, httpMethod as dB, parseBasicAuth as dC, fetchBasic as dD, fetchJson as dE, fetchText as dF, fetchOptionsFormURLEncoded as dG, fetchOptionsJson as dH, fetchOptionsBasicAuth as dI, getWindow as dJ, getNavigator as dK, getGlobal as dL, detect as dM, isBrowser as dN, platform as dO, useExitHandler as dP, MemStorageOptions as dQ, MemStorage as dR, getTimestamp as dS, formatMilliseconds as dT, parseDate as dU, NestedArray as dV, uuidBytes as dW, uuidB62 as dX, uuidEncodeB62 as dY, uuidDecodeB62 as dZ, uuidB32 as d_, Emitter as da, getGlobalEmitter as db, messages as dc, lazyListener as dd, Encoder as de, NoopEncoder as df, JsonEncoder as dg, CryptoEncoder as dh, MessageAction as di, MessageResult as dj, Message as dk, MessagesOptions as dl, MessagesDefaultMethods as dm, MessagesMethods as dn, MessageDefinitions as dp, MessageHub as dq, createPromiseProxy as dr, useMessageHub as ds, PubSub as dt, usePubSub as du, ArgumentsType as dv, ReturnType$1 as dw, RPCOptions as dx, RPCFn as dy, RPCReturn as dz, CRYPTO_DEFAULT_DERIVE_ALG as e, uuidDecodeB32 as e0, uuidv4 as e1, uuidEncodeV4 as e2, uuidDecodeV4 as e3, suidBytes as e4, suid as e5, suidDate as e6, suidBytesDate as e7, uuid32bit as e8, setUuidDefaultEncoding as e9, uuid as ea, uuidDecode as eb, uuidEncode as ec, uuidIsValid as ed, uname as ee, qid as ef, CRYPTO_DEFAULT_DERIVE_ITERATIONS as f, digest as g, deriveKeyPbkdf2 as h, encrypt as i, decrypt as j, csv as k, arrayUnique as l, arrayMinus as m, arrayUnion as n, arrayFlatten as o, arrayIntersection as p, arraySymmetricDifference as q, randomUint8Array as r, arrayRemoveElement as s, arraySetElement as t, arrayFilterInPlace as u, arrayToggleInPlace as v, arrayEmptyInPlace as w, arraySorted as x, arraySortedNumbers as y, arrayIsEqual as z };
